==> blobAndConquer-0.1-1.tar.gz: BlobAndConquer/src/main.cpp <==
/*
Copyright (C) 2005 Parallel Realities

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.

See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

*/

#include "main.h"

void showHelp()
{
	SDL_Init(SDL_INIT_VIDEO);
	
	graphics->getAvailableScreenModes();
	
	printf("\n");
	printf("Blob Wars, Episode II - Blob And Conquer (Version %.2f, Release %d)\n", VERSION, RELEASE);
	printf("Copyright (C) 2005 Parallel Realities\n");
	printf("Licensed under the GNU General Public License (GPL)\n\n");

	printf("The Blob And Conquer gameplay manual can be found in,\n");
	printf("\t%s\n\n", GAMEPLAYMANUAL);

	printf("Additional Commands\n");
	printf("\t-language <lang>    Start the game using specified language,\n");
	
	List *list = localeManager->localeIndex.getTable()->toList();
	Data *data;
	Reference *ref;
	
	for (int i = 0 ; i < list->getSize() ; i++)
	{
		ref = (Reference*)list->getElement(i);
		data = (Data*)ref->object;
		printf("\t                    %s (%s)\n", data->getKey(), data->getValue());
	}
	
	printf("\t-fullscreen         Start the game in fullscreen mode (default)\n");
	printf("\t-window             Start the game in windowed mode\n");
	
	for (int i = 0 ; i < 10 ; i++)
	{
		if (graphics->screenMode[i].w == 0)
		{
			continue;
		}
		
		if (i == 0)
		{
			printf("\t-screensize         %d - %d x %d\n", i, graphics->screenMode[i].w, graphics->screenMode[i].h);
		}
		else
		{
			printf("\t                    %d - %d x %d\n", i, graphics->screenMode[i].w, graphics->screenMode[i].h);
		}
	}
	
	printf("\t-mono               Use mono sound\n");
	printf("\t-stereo             Use stereo sound (default)\n");
	printf("\t-noaudio            Disables audio\n");
	printf("\t-version            Display version number\n");
	printf("\t--help              This help\n\n");

	exit(0);
}

void showVersion()
{
	printf("\n");
	printf("Blob Wars, Episode II - Blob And Conquer (Version %.2f, Release %d)\n", VERSION, RELEASE);
	printf("Copyright (C) 2005 Parallel Realities\n");
	printf("Licensed under the GNU General Public License (GPL)\n\n");
	exit(0);
}

int main(int argc, char *argv[])
{
	atexit(cleanup);
	
	loadLocaleIndex();
	
	game->saveSlot = -1;
	String mission;
	int requiredSection = SECTION_TITLE;
	
	for (int i = 1 ; i < argc ; i++)
	{
		if (strcmp(argv[i], "-fullscreen") == 0) graphics->fullscreen = true;
		else if (strcmp(argv[i], "-language") == 0) localeManager->setLanguage(argv[++i]);
		else if (strcmp(argv[i], "-noaudio") == 0) audio->useAudio = 0;
		else if (strcmp(argv[i], "-mono") == 0) audio->useAudio = 1;
		else if (strcmp(argv[i], "-version") == 0) showVersion();
		else if (strcmp(argv[i], "--help") == 0) showHelp();
		else if (strcmp(argv[i], "-mission") == 0) mission = argv[++i];
		else if (strcmp(argv[i], "-load") == 0) game->saveSlot = atoi(argv[++i]);
		else if (strcmp(argv[i], "-nomonsters") == 0) game->nomonsters = true;
		else if (strcmp(argv[i], "-noitems") == 0) game->noitems = true;
		else if (strcmp(argv[i], "-allstatic") == 0) game->allStatic = true;
	}
	
	initSystem();
	
	initOpenGL();
	
	loadAllDefinitions();
	
	removeUnneededResources();
	
	if (game->saveSlot != -1)
	{
		requiredSection = SECTION_LOAD;
	}
	else if (mission != "")
	{
		game->targetLocation = "default";
		game->mission = mission.getText();
		loadMission(game->mission.getText());
		requiredSection = SECTION_BATTLE;
	}
	
	while (true)
	{
		if (requiredSection != SECTION_BATTLE)
		{
			removeUnneededResources();
		}
		
		switch (requiredSection)
		{
			case SECTION_TITLE:
				requiredSection = doTitle();
				break;
				
			case SECTION_NEWGAME:
				game->mission = "mission1";
				game->targetLocation = "default";
				loadMission(game->mission.getText());
				requiredSection = SECTION_BATTLE;
				break;
				
			case SECTION_TRAINING:
				game->training = true;
				loadMission("training");
				requiredSection = SECTION_BATTLE;
				break;
				
			case SECTION_BATTLE:
				requiredSection = mainBattleLoop();
				break;
				
			case SECTION_CHANGE_LEVEL:
				game->mission = game->targetMission.getText();
				loadMissionOrSave(game->mission.getText());
				requiredSection = SECTION_BATTLE;
				break;
				
			case SECTION_GAMEOVER:
				requiredSection = doGameOver();
				break;
				
			case SECTION_LOAD:
				game->targetLocation = "@none@";
				loadGameData(game->saveSlot);
				requiredSection = SECTION_BATTLE;
				break;
		}
	}
	
	debug(("main() Exitting\n"));
	
	return 0;
}

==> blobAndConquer-0.2-1.tar.gz: BlobAndConquer/src/main.cpp <==
/*
Copyright (C) 2005 Parallel Realities

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.

See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

*/

#include "main.h"

void showHelp()
{
	SDL_Init(SDL_INIT_VIDEO);
	
	graphics->getAvailableScreenModes();
	
	printf("\n");
	printf("Blob Wars, Episode II - Blob And Conquer (Version %.2f, Release %d)\n", VERSION, RELEASE);
	printf("Copyright (C) 2005 Parallel Realities\n");
	printf("Licensed under the GNU General Public License (GPL)\n\n");

	printf("The Blob And Conquer gameplay manual can be found in,\n");
	printf("\t%s\n\n", GAMEPLAYMANUAL);

	printf("Additional Commands\n");
	printf("\t-language <lang>    Start the game using specified language,\n");
	
	List *list = localeManager->localeIndex.getTable()->toList();
	Data *data;
	Reference *ref;
	
	for (int i = 0 ; i < list->getSize() ; i++)
	{
		ref = (Reference*)list->getElement(i);
		data = (Data*)ref->object;
		printf("\t                    %s (%s)\n", data->getKey(), data->getValue());
	}
	
	/*
	printf("\t-fullscreen         Start the game in fullscreen mode (default)\n");
	printf("\t-window             Start the game in windowed mode\n");
	
	for (int i = 0 ; i < 10 ; i++)
	{
		if (graphics->screenMode[i].w == 0)
		{
			continue;
		}
		
		if (i == 0)
		{
			printf("\t-screensize         %d - %d x %d\n", i, graphics->screenMode[i].w, graphics->screenMode[i].h);
		}
		else
		{
			printf("\t                    %d - %d x %d\n", i, graphics->screenMode[i].w, graphics->screenMode[i].h);
		}
	}
	
	printf("\t-mono               Use mono sound\n");
	printf("\t-stereo             Use stereo sound (default)\n");
	printf("\t-noaudio            Disables audio\n");
	*/
	printf("\t-version            Display version number\n");
	printf("\t--help              This help\n\n");

	exit(0);
}

void showVersion()
{
	printf("\n");
	printf("Blob Wars, Episode II - Blob And Conquer (Version %.2f, Release %d)\n", VERSION, RELEASE);
	printf("Copyright (C) 2005 Parallel Realities\n");
	printf("Licensed under the GNU General Public License (GPL)\n\n");
	exit(0);
}

int main(int argc, char *argv[])
{
	atexit(cleanup);
	
	loadLocaleIndex();
	
	game->saveSlot = -1;
	String mission;
	int requiredSection = SECTION_TITLE;
	
	for (int i = 1 ; i < argc ; i++)
	{
		if (strcmp(argv[i], "-fullscreen") == 0) graphics->fullscreen = true;
		else if (strcmp(argv[i], "-language") == 0) localeManager->setLanguage(argv[++i]);
		else if (strcmp(argv[i], "-noaudio") == 0) audio->useAudio = 0;
		else if (strcmp(argv[i], "-mono") == 0) audio->useAudio = 1;
		else if (strcmp(argv[i], "-version") == 0) showVersion();
		else if (strcmp(argv[i], "--help") == 0) showHelp();
		else if (strcmp(argv[i], "-mission") == 0) {mission = argv[++i]; game->testing = true;}
		else if (strcmp(argv[i], "-load") == 0) game->saveSlot = atoi(argv[++i]);
		else if (strcmp(argv[i], "-nomonsters") == 0) game->nomonsters = true;
		else if (strcmp(argv[i], "-noitems") == 0) game->noitems = true;
		else if (strcmp(argv[i], "-allstatic") == 0) game->allStatic = true;
	}
	
	initSystem();
	
	initOpenGL();
	
	loadAllDefinitions();
	
	removeUnneededResources();
	
	if (game->saveSlot != -1)
	{
		requiredSection = SECTION_LOAD;
	}
	else if (mission != "")
	{
		game->targetLocation = "default";
		game->mission = mission.getText();
		loadMission(game->mission.getText());
		requiredSection = SECTION_BATTLE;
	}
	
	while (true)
	{
		if (requiredSection != SECTION_BATTLE)
		{
			removeUnneededResources();
		}
		
		switch (requiredSection)
		{
			case SECTION_TITLE:
				requiredSection = doTitle();
				break;
				
			case SECTION_NEWGAME:
				game->mission = "mission1";
				game->targetLocation = "default";
				loadMission(game->mission.getText());
				requiredSection = SECTION_BATTLE;
				break;
				
			case SECTION_TRAINING:
				game->training = true;
				loadMission("training");
				requiredSection = SECTION_BATTLE;
				break;
				
			case SECTION_BATTLE:
				requiredSection = mainBattleLoop();
				break;
				
			case SECTION_CHANGE_LEVEL:
				game->mission = game->targetMission.getText();
				loadMissionOrSave(game->mission.getText());
				requiredSection = SECTION_BATTLE;
				break;
				
			case SECTION_GAMEOVER:
				requiredSection = doGameOver();
				break;
				
			case SECTION_LOAD:
				game->targetLocation = "@none@";
				loadGameData(game->saveSlot);
				requiredSection = SECTION_BATTLE;
				break;
		}
	}
	
	debug(("main() Exitting\n"));
	
	return 0;
}
